<?php

namespace Module\CustomForm\CustomForm\Controller;

use Application;
use Boutique;
use ByDedi\Module\CustomForm\Service\ResponseFactory;
use ByDedi\Module\CustomForm\Model\FormEntity;
use ByDedi\Module\CustomForm\Service\FormFromEntity;
use ByDedi\Module\CustomForm\Service\FilledFormFromEntity;
use Controller\Controller;
use EmailSender;
use Form\Field;
use Form\FullForm\FieldInterface;
use Mailer;
use Module\CustomForm\CustomForm\Model\ActiveFormEntity;
use Symfony\Component\HttpFoundation\Request;

use Symfony\Component\Routing\Annotation\Route;

final class FormController extends Controller
{
    /**
     * @Route(
     *      path         = "/submit_custom_form_{id}",
     *      name         = "submit_custom_form",
     *      requirements = { "id" = "[0-9]+" },
     *      methods      = { "POST" }
     * )
     * @throws \Exception
     */
    public function submit_custom_form()
    {
        /** @var Request $request */
        $request = $this->request;
        $flashbag = $this->getFlashBag();

        $form = new FormFromEntity(new ActiveFormEntity($request->get("id")));
        $filledForm = new FilledFormFromEntity($form, $request);

        if ($filledForm->isValid()) {
            $responseFactory = new ResponseFactory();
            $responseEntity = $responseFactory->generate($filledForm);
            $saved_id = $responseEntity->save();

            if (!empty($saved_id)) {
                $flashbag->set("success", $filledForm->getSuccessText());
            }

            $fields = $filledForm->getFieldsByTag("sujet");
            $emails = [];
            foreach ($fields as $field) {
                $selectedOption = $field->getSelectedValue();
                $emails[] = $selectedOption->form_field_option_email;
            }

            if(!empty($emails)) {

                $mailer = Application::getEmailSender();
                $from = array(Boutique::getInstance()->contactEmail => Boutique::getInstance()->nom);
                $subject = "Un formulaire à été posté depuis votre site internet";
                $body = $this->template->fetch("email_form.tpl", ["response" => $responseEntity]);

                foreach ($emails as $to) {
                    $mailer->send(EmailSender::createMessage($to, $subject, $body, $from, []));
                }
            }

        } else {
            $flashbag->add("form", $filledForm);
            $fields = $filledForm->getFields();
            $error = array_reduce($fields, function (array $error, FieldInterface $field) {
                if ($field->hasError()) {
                    array_push($error, $field->getError());
                }
                return $error;
            }, []);
            $flashbag->set("error", $error);
        }

        // Retours au formulaire de base
        return $this->redirect($this->request->server->get("HTTP_REFERER"));
    }
}