<?php

namespace ByDedi\Module\CustomForm\Controller;

use ByDedi\Module\CustomForm\Model\FormEntity;
use ByDedi\Module\CustomForm\Service\FieldFromEntity;
use ByDedi\Module\CustomForm\Service\FormFromEntity;
use Controller\Controller;
use Form\FullForm\FieldInterface;
use Module\CustomForm\CustomForm\Model\ActiveFormEntity;
use Symfony\Component\HttpFoundation\Request;

final class RenderController extends Controller
{
    public function __construct(Request $request)
    {
        parent::__construct($request);

        // on ajoute un dossier de template
        $this->template->addTemplateDir(__DIR__ . '/../Resources/views');
    }


    /**
     * @return \Symfony\Component\HttpFoundation\Response
     * @throws \SmartyException
     * @throws \Exception
     */
    public function show()
    {
        $form_id = $this->request->get("form_id");
        $form = new ActiveFormEntity($form_id);
        $this->template->assign("form", new FormFromEntity($form));

        $flashbag = $this->getFlashBag();

        $this->template->assign("error", $flashbag->get("error"));
        $this->template->assign("success", $flashbag->get("success"));
        return $this->fetch("customForm.tpl");
    }

    /**
     * @return \Symfony\Component\HttpFoundation\Response
     * @throws \SmartyException
     */
    public function showField() {
        /** @var FieldFromEntity $field */
        $field = $this->request->get('field');

        switch ($field->getTypeId())
        {
            case FieldInterface::TYPE_TEXT_ID :
                $return = "parts/text.tpl";
                break;
            case FieldInterface::TYPE_TEXTAREA_ID :
                $return = "parts/textarea.tpl";
                break;
            case FieldInterface::TYPE_SELECT_ID:
                $return = "parts/select.tpl";
                break;
            case FieldInterface::TYPE_CHECKBOX_ID :
                $return = "parts/checkbox.tpl";
                break;
            case FieldInterface::TYPE_RADIO_ID :
                $return = "parts/radio.tpl";
                break;
            case FieldInterface::TYPE_FILE_ID :
                $return = "parts/file.tpl";
                break;
            case FieldInterface::TYPE_SUBMIT_ID :
                $return = "parts/submit.tpl";
                break;
            default :
                throw new ResourceNotFoundException("Unknown field tpl !");
                break;
        }

        $this->template->assign("field", $field);
        return $this->fetch($return);
    }
}