<?php

namespace ByDedi\Module\CustomForm\Model;

use Boutique;

/**
 * Class CustomForm
 *
 * @property int      $form_id
 * @property string   $form_nom_success
 * @property string   form_nom_submit_text
 * @property \SiteSQL form_nom_rgpd
 */
class FormEntity extends Model implements FormEntityInterface
{
    const FORM_STATUT_ACTIVE = 1;

    /**
     * @var string
     */
    protected $table = "form";

    /**
     * @var FieldEntity[]
     */
    protected $fields;

    /**
     * @return FieldEntity[]
     */
    public function getFields()
    {
        if ($this->fields === null) {
            if (empty($this->getId())) {
                return [];
            }

            $field = new FieldEntity();
            $this->fields = $field->getByForm($this);
        }

        return $this->fields;
    }

    /**
     * @return int
     */
    public function getId()
    {
        return $this->form_id;
    }

    /**
     * {@inheritdoc}
     */
    public function getSuccessText()
    {
        return $this->form_nom_success;
    }

    /**
     * {@inheritdoc}
     */
    public function getSubmitButtonText()
    {
        return $this->form_nom_submit_text;
    }

    /**
     * {@inheritdoc}
     */
    public function getRgpdText()
    {
        return $this->form_nom_rgpd;
    }

    public function duplicate()
    {
        // Récupération de ces champs
        $fields = $this->getFields();
        // Nullification de l'objet
        $this->form_id = null;
        $this->form_nom_id = null;
        // Création d'une nouvelle entrée en base
        $form_id = $this->save();

        // Duplication des fields
        foreach ($fields as $field) {
            // Récupération des options / containtes field
            $constrains = $field->getConstraints();
            $options = $field->getOptions();

            // Nullification des fiels
            $field->form_field_id = null;
            $field->form_field_nom_id = null;
            // Sauvergarde des doubles
            $form_field_id = $field->save();
            // Liaison au form dupliquer
            $this->sql->save("form_form_field", ["form_field_id" => $form_field_id, "form_id" => $form_id]);

            // Duplication des contraintes
            foreach ($constrains as $constrain) {
                $constrain->form_field_constraint_id = null;
                $constrain->form_field_constraint_nom_id = null;
                $constrain->form_field_id = $form_field_id;
                $constrain->save();
            }

            // Duplication des options
            foreach ($options as $option) {
                $option->form_field_option_id = null;
                $option->form_field_option_nom_id = null;
                $option->form_field_id = $form_field_id;
                $option->save();
            }
        }

        return $form_id;
    }
}